var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/*
 * @author: liuhy
 * @Date: 2021-04-06 09:54:25
 * @LastEditTime: 2021-04-12 10:11:42
 */

/**
 * 深复制
 *
 * @export
 * @param {*} source
 * @returns
 */
export function copy(source) {
  if (!source && (typeof source === 'undefined' ? 'undefined' : _typeof(source)) !== 'object') {
    throw new Error('error arguments', 'shallowClone');
  }
  var targetObj = source.constructor === Array ? [] : {};
  for (var keys in source) {
    if (source.hasOwnProperty(keys)) {
      if (source[keys] && _typeof(source[keys]) === 'object') {
        targetObj[keys] = source[keys].constructor === Array ? [] : {};
        targetObj[keys] = copy(source[keys]);
      } else {
        targetObj[keys] = source[keys];
      }
    }
  }
  return targetObj;
}

/**
 * 一维数组转二维数组
 * @param {*} data 
 */
export function oneArrToTwoArr(data) {
  var n = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;

  var objArray = data;
  var len = objArray.length;
  // let n = 2; //假设每行显示2个
  var lineNum = len % n === 0 ? len / n : Math.floor(len / n + 1);
  var res = [];
  for (var i = 0; i < lineNum; i++) {
    var temp = objArray.slice(i * n, i * n + n);
    res.push(copy(temp));
  }
  return res;
}

/**
 * 时间格式化
 * dateFormat("YYYY-mm-dd HH:MM", date)
 * 2019-06-06 19:45
 */
export function dateFormat(fmt, date) {
  var ret = void 0;
  var opt = {
    "Y+": date.getFullYear().toString(), // 年
    "m+": (date.getMonth() + 1).toString(), // 月
    "d+": date.getDate().toString(), // 日
    "H+": date.getHours().toString(), // 时
    "M+": date.getMinutes().toString(), // 分
    "S+": date.getSeconds().toString() // 秒
    // 有其他格式化字符需求可以继续添加，必须转化成字符串
  };
  for (var k in opt) {
    ret = new RegExp("(" + k + ")").exec(fmt);
    if (ret) {
      fmt = fmt.replace(ret[1], ret[1].length == 1 ? opt[k] : opt[k].padStart(ret[1].length, "0"));
    };
  };
  return fmt;
}

/**
 * 获取当前周从星期一到星期天的日期
 */
export function getWeekDates(currentTime) {
  //JS获取当前周从星期一到星期天的日期
  // let currentDate = new Date(currentTime)
  // let timesStamp = currentDate.getTime();
  // let currenDay = currentDate.getDay();
  // const dates = [];
  // for (var i = 0; i < 7; i++) {
  //     dates.push(new Date(timesStamp + 24 * 60 * 60 * 1000 * (i - (currenDay + 6) % 7)).toLocaleDateString().replace(/\//g, '-'));
  var now = new Date(currentTime);
  var now_day = now.getDay();
  var now_time = now.getTime();
  var result = [{ week: '周日', w: 0 }, { week: '周一', w: 1 }, { week: '周二', w: 2 }, { week: '周三', w: 3 }, { week: '周四', w: 4 }, { week: '周五', w: 5 }, { week: '周六', w: 6 }];
  var dates = [];
  result.map(function (i) {
    dates.push({ week: i.week, day: new Date(now_time + 24 * 60 * 60 * 1000 * (i.w - now_day)).getDate() });
  });
  return dates;
}

/**
 * 新增组件的配置时，旧客户不重新拖进去配置的话，该属性的值是未定义的。
 * 为了兼容之前的客户，需要校验配置项的值
 */

export function verifyProp(propName, props) {
  if (propName in props && typeof props[propName] !== 'undefined') {
    // 组件生效了的时候直接返回该属性的值
    return props[propName];
  } else {
    // 组件未生效时或者旧客户使用的组件时，返回default字符串
    return 'default';
  }
}